# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.1.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medparameter
else:
    import _medparameter

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medparameter_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medparameter.delete_SwigPyIterator_medparameter_module

    def value(self):
        return _medparameter.SwigPyIterator_medparameter_module_value(self)

    def incr(self, n=1):
        return _medparameter.SwigPyIterator_medparameter_module_incr(self, n)

    def decr(self, n=1):
        return _medparameter.SwigPyIterator_medparameter_module_decr(self, n)

    def distance(self, x):
        return _medparameter.SwigPyIterator_medparameter_module_distance(self, x)

    def equal(self, x):
        return _medparameter.SwigPyIterator_medparameter_module_equal(self, x)

    def copy(self):
        return _medparameter.SwigPyIterator_medparameter_module_copy(self)

    def next(self):
        return _medparameter.SwigPyIterator_medparameter_module_next(self)

    def __next__(self):
        return _medparameter.SwigPyIterator_medparameter_module___next__(self)

    def previous(self):
        return _medparameter.SwigPyIterator_medparameter_module_previous(self)

    def advance(self, n):
        return _medparameter.SwigPyIterator_medparameter_module_advance(self, n)

    def __eq__(self, x):
        return _medparameter.SwigPyIterator_medparameter_module___eq__(self, x)

    def __ne__(self, x):
        return _medparameter.SwigPyIterator_medparameter_module___ne__(self, x)

    def __iadd__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___iadd__(self, n)

    def __isub__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___isub__(self, n)

    def __add__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___add__(self, n)

    def __sub__(self, *args):
        return _medparameter.SwigPyIterator_medparameter_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medparameter_module in _medparameter:
_medparameter.SwigPyIterator_medparameter_module_swigregister(SwigPyIterator_medparameter_module)
HAVE_CC_C99 = _medparameter.HAVE_CC_C99
HAVE_CUSERID = _medparameter.HAVE_CUSERID
HAVE_DLFCN_H = _medparameter.HAVE_DLFCN_H
HAVE_FTIME = _medparameter.HAVE_FTIME
HAVE_GETEUID = _medparameter.HAVE_GETEUID
HAVE_GETPWUID = _medparameter.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medparameter.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medparameter.HAVE_H5PUBLIC_H
HAVE_INT64 = _medparameter.HAVE_INT64
HAVE_INTTYPES_H = _medparameter.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medparameter.HAVE_MALLOC_H
HAVE_PWD_H = _medparameter.HAVE_PWD_H
HAVE_STDBOOL_H = _medparameter.HAVE_STDBOOL_H
HAVE_STDINT_H = _medparameter.HAVE_STDINT_H
HAVE_STDIO_H = _medparameter.HAVE_STDIO_H
HAVE_STDLIB_H = _medparameter.HAVE_STDLIB_H
HAVE_STRINGS_H = _medparameter.HAVE_STRINGS_H
HAVE_STRING_H = _medparameter.HAVE_STRING_H
HAVE_SYS_STAT_H = _medparameter.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medparameter.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medparameter.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medparameter.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medparameter.HAVE_UNISTD_H
HAVE__BOOL = _medparameter.HAVE__BOOL
MED_CHECK_23FORMAT = _medparameter.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medparameter.MED_HAVE_FORTRAN
MESGERR = _medparameter.MESGERR
PACKAGE = _medparameter.PACKAGE
PACKAGE_BUGREPORT = _medparameter.PACKAGE_BUGREPORT
PACKAGE_NAME = _medparameter.PACKAGE_NAME
PACKAGE_STRING = _medparameter.PACKAGE_STRING
PACKAGE_URL = _medparameter.PACKAGE_URL
PACKAGE_VERSION = _medparameter.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medparameter.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medparameter.SIZEOF_INT
SIZEOF_LONG = _medparameter.SIZEOF_LONG
STDC_HEADERS = _medparameter.STDC_HEADERS
VERSION = _medparameter.VERSION
HDF_VERSION_REF = _medparameter.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medparameter.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medparameter.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medparameter.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medparameter.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medparameter.H5F_LIBVER_18
MED_MAJOR_NUM = _medparameter.MED_MAJOR_NUM
MED_MINOR_NUM = _medparameter.MED_MINOR_NUM
MED_RELEASE_NUM = _medparameter.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medparameter.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medparameter.MED_4_LATEST_MINOR
MED_40_LATEST_RELEASE = _medparameter.MED_40_LATEST_RELEASE
MED_NUM_MAJEUR = _medparameter.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medparameter.MED_NUM_MINEUR
MED_NUM_RELEASE = _medparameter.MED_NUM_RELEASE
MED_VERSION_STR = _medparameter.MED_VERSION_STR
MED_MAX_PARA = _medparameter.MED_MAX_PARA
MED_COMMENT_SIZE = _medparameter.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medparameter.MED_IDENT_SIZE
MED_NAME_SIZE = _medparameter.MED_NAME_SIZE
MED_SNAME_SIZE = _medparameter.MED_SNAME_SIZE
MED_LNAME_SIZE = _medparameter.MED_LNAME_SIZE
MED_SNAME_BLANK = _medparameter.MED_SNAME_BLANK
MED_NAME_BLANK = _medparameter.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medparameter.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medparameter.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medparameter.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medparameter.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medparameter.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medparameter.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medparameter.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medparameter.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medparameter.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medparameter.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medparameter.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medparameter.MED_ACC_RDONLY
MED_ACC_RDWR = _medparameter.MED_ACC_RDWR
MED_ACC_RDEXT = _medparameter.MED_ACC_RDEXT
MED_ACC_CREAT = _medparameter.MED_ACC_CREAT
MED_ACC_UNDEF = _medparameter.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medparameter.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medparameter.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medparameter.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medparameter.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medparameter.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medparameter.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medparameter.MED_UNDEF_GRID_TYPE
MED_CELL = _medparameter.MED_CELL
MED_DESCENDING_FACE = _medparameter.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medparameter.MED_DESCENDING_EDGE
MED_NODE = _medparameter.MED_NODE
MED_NODE_ELEMENT = _medparameter.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medparameter.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medparameter.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medparameter.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medparameter.MED_N_ENTITY_TYPES
MED_COORDINATE = _medparameter.MED_COORDINATE
MED_CONNECTIVITY = _medparameter.MED_CONNECTIVITY
MED_NAME = _medparameter.MED_NAME
MED_NUMBER = _medparameter.MED_NUMBER
MED_FAMILY_NUMBER = _medparameter.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medparameter.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medparameter.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medparameter.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medparameter.MED_INDEX_FACE
MED_INDEX_NODE = _medparameter.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medparameter.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medparameter.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medparameter.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medparameter.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medparameter.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medparameter.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medparameter.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medparameter.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medparameter.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medparameter.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medparameter.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medparameter.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medparameter.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medparameter.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medparameter.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medparameter.MED_INTERNAL_UNDEF
MED_DOUBLE = _medparameter.MED_DOUBLE
MED_FLOAT64 = _medparameter.MED_FLOAT64
MED_FLOAT32 = _medparameter.MED_FLOAT32
MED_INT32 = _medparameter.MED_INT32
MED_INT64 = _medparameter.MED_INT64
MED_INT = _medparameter.MED_INT
MED_ATT_FLOAT64 = _medparameter.MED_ATT_FLOAT64
MED_ATT_INT = _medparameter.MED_ATT_INT
MED_ATT_NAME = _medparameter.MED_ATT_NAME
MED_ATT_UNDEF = _medparameter.MED_ATT_UNDEF
MED_MESH = _medparameter.MED_MESH
MED_FIELD = _medparameter.MED_FIELD
MED_LIBRARY = _medparameter.MED_LIBRARY
MED_FILE = _medparameter.MED_FILE
MED_MESH_SUPPORT = _medparameter.MED_MESH_SUPPORT
MED_ELSTRUCT = _medparameter.MED_ELSTRUCT
MED_FAMILY = _medparameter.MED_FAMILY
MED_EQUIVALENCE = _medparameter.MED_EQUIVALENCE
MED_GROUP = _medparameter.MED_GROUP
MED_JOINT = _medparameter.MED_JOINT
MED_LOCALIZATION = _medparameter.MED_LOCALIZATION
MED_PROFILE = _medparameter.MED_PROFILE
MED_FILTER = _medparameter.MED_FILTER
MED_INTERPOLATION = _medparameter.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medparameter.MED_NUMERICAL_DATA
MED_LINK = _medparameter.MED_LINK
MED_CLASS_UNDEF = _medparameter.MED_CLASS_UNDEF
MED_CLASS_ALL = _medparameter.MED_CLASS_ALL
MED_POINT1 = _medparameter.MED_POINT1
MED_SEG2 = _medparameter.MED_SEG2
MED_SEG3 = _medparameter.MED_SEG3
MED_SEG4 = _medparameter.MED_SEG4
MED_TRIA3 = _medparameter.MED_TRIA3
MED_QUAD4 = _medparameter.MED_QUAD4
MED_TRIA6 = _medparameter.MED_TRIA6
MED_TRIA7 = _medparameter.MED_TRIA7
MED_QUAD8 = _medparameter.MED_QUAD8
MED_QUAD9 = _medparameter.MED_QUAD9
MED_TETRA4 = _medparameter.MED_TETRA4
MED_PYRA5 = _medparameter.MED_PYRA5
MED_PENTA6 = _medparameter.MED_PENTA6
MED_HEXA8 = _medparameter.MED_HEXA8
MED_TETRA10 = _medparameter.MED_TETRA10
MED_OCTA12 = _medparameter.MED_OCTA12
MED_PYRA13 = _medparameter.MED_PYRA13
MED_PENTA15 = _medparameter.MED_PENTA15
MED_PENTA18 = _medparameter.MED_PENTA18
MED_HEXA20 = _medparameter.MED_HEXA20
MED_HEXA27 = _medparameter.MED_HEXA27
MED_POLYGON = _medparameter.MED_POLYGON
MED_POLYGON2 = _medparameter.MED_POLYGON2
MED_POLYHEDRON = _medparameter.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medparameter.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medparameter.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medparameter.MED_NONE
MED_NO_GEOTYPE = _medparameter.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medparameter.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medparameter.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medparameter.MED_ALL_GEOTYPE
MED_GEO_ALL = _medparameter.MED_GEO_ALL
MED_N_CELL_GEO = _medparameter.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medparameter.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medparameter.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medparameter.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medparameter.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medparameter.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medparameter.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medparameter.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medparameter.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medparameter.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medparameter.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medparameter.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medparameter.MED_NODAL
MED_DESCENDING = _medparameter.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medparameter.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medparameter.MED_NO_CMODE
MED_CARTESIAN = _medparameter.MED_CARTESIAN
MED_CYLINDRICAL = _medparameter.MED_CYLINDRICAL
MED_SPHERICAL = _medparameter.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medparameter.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medparameter.MED_FALSE
MED_TRUE = _medparameter.MED_TRUE
MED_GAUSS_ELNO = _medparameter.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medparameter.MED_IPOINT_ELNO
MED_NO_NAME = _medparameter.MED_NO_NAME
MED_NO_MESHNAME = _medparameter.MED_NO_MESHNAME
MED_NO_MESH = _medparameter.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medparameter.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medparameter.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medparameter.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medparameter.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medparameter.MED_NO_PROFILE
MED_NO_GROUP = _medparameter.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medparameter.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medparameter.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medparameter.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medparameter.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medparameter.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medparameter.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medparameter.MED_SORT_DTIT
MED_SORT_ITDT = _medparameter.MED_SORT_ITDT
MED_SORT_UNDEF = _medparameter.MED_SORT_UNDEF
MED_ALL_DT = _medparameter.MED_ALL_DT
MED_ALL_IT = _medparameter.MED_ALL_IT
MED_NO_DT = _medparameter.MED_NO_DT
MED_NO_IT = _medparameter.MED_NO_IT
MED_UNDEF_DT = _medparameter.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medparameter.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medparameter.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medparameter.med_filter_nspaces_get, _medparameter.med_filter_nspaces_set)
    memspace = property(_medparameter.med_filter_memspace_get, _medparameter.med_filter_memspace_set)
    diskspace = property(_medparameter.med_filter_diskspace_get, _medparameter.med_filter_diskspace_set)
    nentity = property(_medparameter.med_filter_nentity_get, _medparameter.med_filter_nentity_set)
    nvaluesperentity = property(_medparameter.med_filter_nvaluesperentity_get, _medparameter.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medparameter.med_filter_nconstituentpervalue_get, _medparameter.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medparameter.med_filter_constituentselect_get, _medparameter.med_filter_constituentselect_set)
    switchmode = property(_medparameter.med_filter_switchmode_get, _medparameter.med_filter_switchmode_set)
    filterarraysize = property(_medparameter.med_filter_filterarraysize_get, _medparameter.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medparameter.med_filter_filterarray23v30_get, _medparameter.med_filter_filterarray23v30_set)
    profilearraysize = property(_medparameter.med_filter_profilearraysize_get, _medparameter.med_filter_profilearraysize_set)
    storagemode = property(_medparameter.med_filter_storagemode_get, _medparameter.med_filter_storagemode_set)
    profilename = property(_medparameter.med_filter_profilename_get, _medparameter.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medparameter.med_filter_swiginit(self, _medparameter.new_med_filter())
    __swig_destroy__ = _medparameter.delete_med_filter

# Register med_filter in _medparameter:
_medparameter.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medparameter.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medparameter.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medparameter.med_file_version_majeur_get, _medparameter.med_file_version_majeur_set)
    mineur = property(_medparameter.med_file_version_mineur_get, _medparameter.med_file_version_mineur_set)
    release = property(_medparameter.med_file_version_release_get, _medparameter.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medparameter.med_file_version_swiginit(self, _medparameter.new_med_file_version())
    __swig_destroy__ = _medparameter.delete_med_file_version

# Register med_file_version in _medparameter:
_medparameter.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medparameter.med_memfile_app_image_ptr_get, _medparameter.med_memfile_app_image_ptr_set)
    app_image_size = property(_medparameter.med_memfile_app_image_size_get, _medparameter.med_memfile_app_image_size_set)
    ref_count = property(_medparameter.med_memfile_ref_count_get, _medparameter.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medparameter.med_memfile_fapl_image_ptr_get, _medparameter.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medparameter.med_memfile_fapl_image_size_get, _medparameter.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medparameter.med_memfile_fapl_ref_count_get, _medparameter.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medparameter.med_memfile_vfd_image_ptr_get, _medparameter.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medparameter.med_memfile_vfd_image_size_get, _medparameter.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medparameter.med_memfile_vfd_ref_count_get, _medparameter.med_memfile_vfd_ref_count_set)
    flags = property(_medparameter.med_memfile_flags_get, _medparameter.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medparameter.med_memfile_swiginit(self, _medparameter.new_med_memfile())
    __swig_destroy__ = _medparameter.delete_med_memfile

# Register med_memfile in _medparameter:
_medparameter.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medparameter.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medparameter.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medparameter.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medparameter.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medparameter.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medparameter.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medparameter.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medparameter.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medparameter.MED_PARTICLE_NAME
MED_BALL_NAME = _medparameter.MED_BALL_NAME
MED_BEAM_NAME = _medparameter.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medparameter.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medparameter.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medparameter.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDBOOL___bool__(self)

    def __len__(self):
        return _medparameter.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDBOOL_pop(self)

    def append(self, x):
        return _medparameter.MEDBOOL_append(self, x)

    def empty(self):
        return _medparameter.MEDBOOL_empty(self)

    def size(self):
        return _medparameter.MEDBOOL_size(self)

    def swap(self, v):
        return _medparameter.MEDBOOL_swap(self, v)

    def begin(self):
        return _medparameter.MEDBOOL_begin(self)

    def end(self):
        return _medparameter.MEDBOOL_end(self)

    def rbegin(self):
        return _medparameter.MEDBOOL_rbegin(self)

    def rend(self):
        return _medparameter.MEDBOOL_rend(self)

    def clear(self):
        return _medparameter.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medparameter.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medparameter.MEDBOOL_swiginit(self, _medparameter.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medparameter.MEDBOOL_push_back(self, x)

    def front(self):
        return _medparameter.MEDBOOL_front(self)

    def back(self):
        return _medparameter.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medparameter.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDBOOL_capacity(self)
    __swig_destroy__ = _medparameter.delete_MEDBOOL

# Register MEDBOOL in _medparameter:
_medparameter.MEDBOOL_swigregister(MEDBOOL)
cvar = _medparameter.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medparameter.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDFLOAT_pop(self)

    def append(self, x):
        return _medparameter.MEDFLOAT_append(self, x)

    def empty(self):
        return _medparameter.MEDFLOAT_empty(self)

    def size(self):
        return _medparameter.MEDFLOAT_size(self)

    def swap(self, v):
        return _medparameter.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medparameter.MEDFLOAT_begin(self)

    def end(self):
        return _medparameter.MEDFLOAT_end(self)

    def rbegin(self):
        return _medparameter.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medparameter.MEDFLOAT_rend(self)

    def clear(self):
        return _medparameter.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medparameter.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medparameter.MEDFLOAT_swiginit(self, _medparameter.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medparameter.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medparameter.MEDFLOAT_front(self)

    def back(self):
        return _medparameter.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medparameter.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDFLOAT

# Register MEDFLOAT in _medparameter:
_medparameter.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medparameter.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medparameter.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medparameter.MEDFLOAT32_empty(self)

    def size(self):
        return _medparameter.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medparameter.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medparameter.MEDFLOAT32_begin(self)

    def end(self):
        return _medparameter.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medparameter.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medparameter.MEDFLOAT32_rend(self)

    def clear(self):
        return _medparameter.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medparameter.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medparameter.MEDFLOAT32_swiginit(self, _medparameter.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medparameter.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medparameter.MEDFLOAT32_front(self)

    def back(self):
        return _medparameter.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medparameter.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medparameter:
_medparameter.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDINT___bool__(self)

    def __len__(self):
        return _medparameter.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDINT_pop(self)

    def append(self, x):
        return _medparameter.MEDINT_append(self, x)

    def empty(self):
        return _medparameter.MEDINT_empty(self)

    def size(self):
        return _medparameter.MEDINT_size(self)

    def swap(self, v):
        return _medparameter.MEDINT_swap(self, v)

    def begin(self):
        return _medparameter.MEDINT_begin(self)

    def end(self):
        return _medparameter.MEDINT_end(self)

    def rbegin(self):
        return _medparameter.MEDINT_rbegin(self)

    def rend(self):
        return _medparameter.MEDINT_rend(self)

    def clear(self):
        return _medparameter.MEDINT_clear(self)

    def get_allocator(self):
        return _medparameter.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medparameter.MEDINT_swiginit(self, _medparameter.new_MEDINT(*args))

    def push_back(self, x):
        return _medparameter.MEDINT_push_back(self, x)

    def front(self):
        return _medparameter.MEDINT_front(self)

    def back(self):
        return _medparameter.MEDINT_back(self)

    def assign(self, n, x):
        return _medparameter.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDINT_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDINT___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDINT

# Register MEDINT in _medparameter:
_medparameter.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDCHAR___bool__(self)

    def __len__(self):
        return _medparameter.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDCHAR_pop(self)

    def append(self, x):
        return _medparameter.MEDCHAR_append(self, x)

    def empty(self):
        return _medparameter.MEDCHAR_empty(self)

    def size(self):
        return _medparameter.MEDCHAR_size(self)

    def swap(self, v):
        return _medparameter.MEDCHAR_swap(self, v)

    def begin(self):
        return _medparameter.MEDCHAR_begin(self)

    def end(self):
        return _medparameter.MEDCHAR_end(self)

    def rbegin(self):
        return _medparameter.MEDCHAR_rbegin(self)

    def rend(self):
        return _medparameter.MEDCHAR_rend(self)

    def clear(self):
        return _medparameter.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medparameter.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medparameter.MEDCHAR_swiginit(self, _medparameter.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medparameter.MEDCHAR_push_back(self, x)

    def front(self):
        return _medparameter.MEDCHAR_front(self)

    def back(self):
        return _medparameter.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medparameter.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDCHAR

# Register MEDCHAR in _medparameter:
_medparameter.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDparameterCr(fid, paramname, paramtype, description, dtunit):
    r"""
    MEDparameterCr(fid, paramname, paramtype, description, dtunit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    paramtype: enum med_parameter_type const
    description: char const *const
    dtunit: char const *const

    """
    return _medparameter.MEDparameterCr(fid, paramname, paramtype, description, dtunit)

def MEDnParameter(fid):
    r"""
    MEDnParameter(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medparameter.MEDnParameter(fid)

def MEDparameterInfo(fid, paramit):
    r"""
    MEDparameterInfo(fid, paramit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramit: int const

    """
    return _medparameter.MEDparameterInfo(fid, paramit)

def MEDparameterInfoByName(fid, paramname):
    r"""
    MEDparameterInfoByName(fid, paramname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const

    """
    return _medparameter.MEDparameterInfoByName(fid, paramname)

def MEDparameterValueWr(fid, paramname, numdt, numit, dt, value):
    r"""
    MEDparameterValueWr(fid, paramname, numdt, numit, dt, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    value: unsigned char const *const

    """
    return _medparameter.MEDparameterValueWr(fid, paramname, numdt, numit, dt, value)

def MEDparameterValueRd(fid, paramname, numdt, numit, value):
    r"""
    MEDparameterValueRd(fid, paramname, numdt, numit, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    numdt: med_int const
    numit: med_int const
    value: unsigned char *const

    """
    return _medparameter.MEDparameterValueRd(fid, paramname, numdt, numit, value)

def MEDparameterComputationStepInfo(fid, paramname, csit):
    r"""
    MEDparameterComputationStepInfo(fid, paramname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    csit: int const

    """
    return _medparameter.MEDparameterComputationStepInfo(fid, paramname, csit)

